<?php

namespace Drupal\language_suggestion\Controller;

use Drupal\Core\Cache\CacheableJsonResponse;
use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\file\Entity\File;
use GeoIp2\Database\Reader;
use GeoIp2\Exception\AddressNotFoundException;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

class LanguageSuggestionController extends ControllerBase {

  protected $configFactory;

  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory->get('language_suggestion.settings');
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * Get HTTP parameter value.
   */
  public function getHTTPHeaderValue(Request $request) {
    $langcode = '';
    $data = [];
    $parameter = $this->configFactory->get('http_header_parameter');
    if ($this->configFactory->get('language_detection') == 'http_header') {
      $langcode = $request->headers->get($parameter);
    }
    $data['#cache'] = [
      'max-age' => 600,
      'tags' => ['language_suggestion_http_header'],
      'contexts' => [
        'url.query_args',
        'ip',
      ],
    ];
    $response = new CacheableJsonResponse($langcode);
    $response->addCacheableDependency(CacheableMetadata::createFromRenderArray($data));
    return $response;
  }

  /**
   * Get GEOIP country code from database.
   */
  public function getCountryCode(Request $request) {
    $data = '';
    $language_detection = $this->configFactory->get('language_detection');
    if ($language_detection == 'geoip_db') {
      $db_file_id = $this->configFactory->get('geoip_db_file');
      if ($file = File::load($db_file_id)) {
        try {
          $reader = new Reader($file->getFileUri());
          $record = $reader->country($request->getClientIp());
          $data = !empty($record->country->isoCode) ? $record->country->isoCode : '';
        }
        catch (AddressNotFoundException $e) {

        }
      }
    }
    elseif ($language_detection == '_server') {
      if ($_server_param = $this->configFactory->get('_server_parameter')) {
        header('cache-control: no-store', FALSE);
        header('Vary: x-geo-country-code', FALSE);
        $data = !empty($_SERVER[$_server_param]) ? $_SERVER[$_server_param] : '';
      }
    }
    if ($this->configFactory->get('debug')) {
      \Drupal::logger('language_suggestion')->notice('Detected country:' . $data);
    }
    return new JsonResponse(['country' => $data]);
  }

}
